==> haskell-hls-refine-imports-plugin-1.0.5.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refine-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-refine-imports-plugin
version:              1.0.5.0
visibility:           public
id:                   hls-refine-imports-plugin-1.0.5.0-1tvCuD9clA1Hc02zvkgpj
key:                  hls-refine-imports-plugin-1.0.5.0-1tvCuD9clA1Hc02zvkgpj
license:              Apache-2.0
maintainer:           mnf.shih@gmail.com
author:               rayshih
synopsis:             Refine imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  88c30ec67b20594d30df6c10b49c71f7
exposed:              True
exposed-modules:      Ide.Plugin.RefineImports
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-refine-imports-plugin-1.0.5.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-refine-imports-plugin-1.0.5.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refine-imports-plugin
hs-libraries:         HShls-refine-imports-plugin-1.0.5.0-1tvCuD9clA1Hc02zvkgpj
depends:
    aeson-2.1.2.1-A1BsFbrv9iTYSCFmVNKuj base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 ghc-9.2.8
    ghcide-1.10.0.0-CKGW7IohwMv8bMfohQhpec
    hls-explicit-imports-plugin-1.2.1.0-FMlYrGptP23FqfyIG81MRX
    hls-graph-1.9.0.0-4R9BR7KhYQcE9Ltvtwl3t3
    hls-plugin-api-1.6.0.0-4xhiGxwPgz0KxcHu1uN1pA
    lsp-1.6.0.0-AIqSqbIniDC70qkr7eb7mA text-1.2.5.0
    unordered-containers-0.2.20-E7OuZmBexWvK28rs1X57rg

haddock-interfaces:
    /usr/share/doc/haskell-hls-refine-imports-plugin/html/hls-refine-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refine-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-refine-imports-plugin-1.0.5.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refine-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-refine-imports-plugin
version:              1.0.5.0
visibility:           public
id:                   hls-refine-imports-plugin-1.0.5.0-3o0LRJ5ngQNHtA3IEeMhDj
key:                  hls-refine-imports-plugin-1.0.5.0-3o0LRJ5ngQNHtA3IEeMhDj
license:              Apache-2.0
maintainer:           mnf.shih@gmail.com
author:               rayshih
synopsis:             Refine imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f0b3950cd8ce8172f6a58e8c03d10679
exposed:              True
exposed-modules:      Ide.Plugin.RefineImports
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-refine-imports-plugin-1.0.5.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-refine-imports-plugin-1.0.5.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refine-imports-plugin
hs-libraries:         HShls-refine-imports-plugin-1.0.5.0-3o0LRJ5ngQNHtA3IEeMhDj
depends:
    aeson-2.1.2.1-A1BsFbrv9iTYSCFmVNKuj base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 ghc-9.2.8
    ghcide-1.10.0.0-9b5uoYhHFSz3XRArHf5tgp
    hls-explicit-imports-plugin-1.2.1.0-7yTl70HCzKdATmMPrbmCeJ
    hls-graph-1.9.0.0-7Kx1VSUCFSnEbXOmoTUVM
    hls-plugin-api-1.6.0.0-1R0dXSBU3kB6HlLBoG0nJK
    lsp-1.6.0.0-AIqSqbIniDC70qkr7eb7mA text-1.2.5.0
    unordered-containers-0.2.20-E7OuZmBexWvK28rs1X57rg

haddock-interfaces:
    /usr/share/doc/haskell-hls-refine-imports-plugin/html/hls-refine-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refine-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
